summaryrefslogtreecommitdiff
path: root/src/loading/fs.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/loading/fs.rs')
-rw-r--r--src/loading/fs.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/loading/fs.rs b/src/loading/fs.rs
index 4c46c80c..3f4a45e1 100644
--- a/src/loading/fs.rs
+++ b/src/loading/fs.rs
@@ -1,7 +1,7 @@
use std::fs::{self, File};
use std::io;
use std::path::Path;
-use std::rc::Rc;
+use std::sync::Arc;
use memmap2::Mmap;
use same_file::Handle;
@@ -35,10 +35,10 @@ impl FsLoader {
self
}
/// Builder-style method to wrap the loader in an [`Rc`] to make it usable
/// with the [`Context`](crate::Context).
- pub fn wrap(self) -> Rc<Self> {
- Rc::new(self)
+ pub fn wrap(self) -> Arc<Self> {
+ Arc::new(self)
}
/// Search for fonts in the operating system's font directories.
@@ -35,10 +35,10 @@ impl FsLoader {
self
}
- /// Builder-style method to wrap the loader in an [`Rc`] to make it usable
+ /// Builder-style method to wrap the loader in an [`Arc`] to make it usable
/// with the [`Context`](crate::Context).